// /qt/qml/org/kde/itinerary/pkpass/GenericPassBackground.qml
#include <QtQml/qqmlprivate.h>
#include <QtCore/qdatetime.h>
#include <QtCore/qobject.h>
#include <QtCore/qstring.h>
#include <QtCore/qstringlist.h>
#include <QtCore/qtimezone.h>
#include <QtCore/qurl.h>
#include <QtCore/qvariant.h>
#include <QtQml/qjsengine.h>
#include <QtQml/qjsprimitivevalue.h>
#include <QtQml/qjsvalue.h>
#include <QtQml/qqmlcomponent.h>
#include <QtQml/qqmlcontext.h>
#include <QtQml/qqmlengine.h>
#include <QtQml/qqmllist.h>
#include <type_traits>
namespace QmlCacheGeneratedCode {
namespace _qt_qml_org_kde_itinerary_pkpass_GenericPassBackground_qml {
extern const unsigned char qmlData alignas(16) [];
extern const unsigned char qmlData alignas(16) [] = {

0x71,0x76,0x34,0x63,0x64,0x61,0x74,0x61,
0x4a,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x4,0xd,0x0,0x0,0xd6,0xfa,0x8c,0x63,
0x32,0x69,0x2b,0xca,0x2c,0x4a,0x22,0xa3,
0x18,0xb0,0x55,0x18,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x23,0x0,0x0,0x0,
0x2c,0x0,0x0,0x0,0x60,0x4,0x0,0x0,
0x8,0x0,0x0,0x0,0xc8,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xe8,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xe8,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xe8,0x0,0x0,0x0,
0x20,0x0,0x0,0x0,0xe8,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x68,0x1,0x0,0x0,
0x2,0x0,0x0,0x0,0x70,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x80,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x80,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x80,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x80,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x80,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x80,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x80,0x1,0x0,0x0,
0xff,0xff,0xff,0xff,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xe0,0xa,0x0,0x0,
0x80,0x1,0x0,0x0,0xe8,0x1,0x0,0x0,
0x58,0x2,0x0,0x0,0xc0,0x2,0x0,0x0,
0x10,0x3,0x0,0x0,0x60,0x3,0x0,0x0,
0xc0,0x3,0x0,0x0,0x10,0x4,0x0,0x0,
0x73,0x0,0x0,0x0,0x90,0x0,0x0,0x0,
0x10,0x2,0x0,0x0,0x73,0x0,0x0,0x0,
0x90,0x0,0x0,0x0,0x20,0x2,0x0,0x0,
0x23,0x0,0x0,0x0,0x30,0x2,0x0,0x0,
0x20,0x2,0x0,0x0,0x73,0x0,0x0,0x0,
0xa0,0x0,0x0,0x0,0x73,0x0,0x0,0x0,
0xa0,0x0,0x0,0x0,0xf3,0x0,0x0,0x0,
0x60,0x2,0x0,0x0,0x73,0x2,0x0,0x0,
0x60,0x2,0x0,0x0,0xe3,0x0,0x0,0x0,
0x80,0x2,0x0,0x0,0xe3,0x0,0x0,0x0,
0x90,0x2,0x0,0x0,0xe3,0x0,0x0,0x0,
0xa0,0x2,0x0,0x0,0xe3,0x0,0x0,0x0,
0xb0,0x2,0x0,0x0,0xf3,0x1,0x0,0x0,
0x73,0x0,0x0,0x0,0xf0,0x1,0x0,0x0,
0x73,0x0,0x0,0x0,0xd0,0x1,0x0,0x0,
0x73,0x0,0x0,0x0,0xf0,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x40,0xd1,0x3f,
0x0,0x0,0x0,0x0,0x0,0x40,0xf5,0x7f,
0x44,0x0,0x0,0x0,0x19,0x0,0x0,0x0,
0xc,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x7,0x0,0x0,0x0,
0x14,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x14,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x0,0x3c,0x1,
0x3c,0x2,0x50,0x8,0x2e,0x3,0x3c,0x4,
0x3c,0x5,0x4c,0x6,0x2e,0x6,0x3c,0x7,
0x3c,0x8,0x18,0x6,0x2,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0x23,0x0,0x0,0x0,
0x11,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0xa,0x0,0x0,0x0,
0x1a,0x0,0x90,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1a,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x9,0x3c,0xa,
0x18,0x7,0x12,0x0,0x6e,0x7,0x50,0x12,
0x12,0x24,0x18,0x8,0x2e,0xb,0x3c,0xc,
0x80,0x8,0x18,0x9,0x12,0x25,0x80,0x9,
0x4c,0x2,0x12,0x0,0x18,0x6,0x2,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0x1b,0x0,0x0,0x0,
0x13,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x8,0x0,0x0,0x0,
0x1b,0x0,0x90,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1b,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0xd,0x3c,0xe,
0x18,0x7,0x2e,0xf,0x3c,0x10,0x68,0x7,
0x50,0x6,0x2e,0x11,0x3c,0x12,0x4c,0x4,
0x2e,0x13,0x3c,0x14,0x18,0x6,0x2,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0x7,0x0,0x0,0x0,
0x15,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x7,0x0,0x0,0x0,
0x1c,0x0,0x90,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1c,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x15,0x3c,0x16,
0x18,0x6,0x2,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0x7,0x0,0x0,0x0,
0x18,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x7,0x0,0x0,0x0,
0x1d,0x0,0x90,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1d,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x17,0x3c,0x18,
0x18,0x6,0x2,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0x14,0x0,0x0,0x0,
0x1b,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x9,0x0,0x0,0x0,
0x1e,0x0,0x90,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1e,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x19,0x18,0x7,
0x2e,0x1a,0x3c,0x1b,0xa2,0x7,0x78,0x18,
0x8,0x10,0x2,0x9e,0x8,0x18,0x6,0x2,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0x7,0x0,0x0,0x0,
0x1e,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x7,0x0,0x0,0x0,
0x20,0x0,0x90,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x20,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x1c,0x3c,0x1d,
0x18,0x6,0x2,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0x7,0x0,0x0,0x0,
0x20,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x7,0x0,0x0,0x0,
0x21,0x0,0x90,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x21,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x1e,0x3c,0x1f,
0x18,0x6,0x2,0x0,0x0,0x0,0x0,0x0,
0x10,0x5,0x0,0x0,0x18,0x5,0x0,0x0,
0x30,0x5,0x0,0x0,0x48,0x5,0x0,0x0,
0x70,0x5,0x0,0x0,0x88,0x5,0x0,0x0,
0xb0,0x5,0x0,0x0,0xc8,0x5,0x0,0x0,
0xd8,0x5,0x0,0x0,0xf8,0x5,0x0,0x0,
0x8,0x6,0x0,0x0,0x20,0x6,0x0,0x0,
0x30,0x6,0x0,0x0,0x60,0x6,0x0,0x0,
0x78,0x6,0x0,0x0,0x88,0x6,0x0,0x0,
0xb0,0x6,0x0,0x0,0xc8,0x6,0x0,0x0,
0xf8,0x6,0x0,0x0,0x10,0x7,0x0,0x0,
0x48,0x7,0x0,0x0,0x70,0x7,0x0,0x0,
0xb8,0x7,0x0,0x0,0xe0,0x7,0x0,0x0,
0x10,0x8,0x0,0x0,0x60,0x8,0x0,0x0,
0x90,0x8,0x0,0x0,0x98,0x8,0x0,0x0,
0xc0,0x8,0x0,0x0,0xc8,0x8,0x0,0x0,
0xe0,0x8,0x0,0x0,0x10,0x9,0x0,0x0,
0x20,0x9,0x0,0x0,0x50,0x9,0x0,0x0,
0x80,0x9,0x0,0x0,0xa8,0x9,0x0,0x0,
0xb8,0x9,0x0,0x0,0xf0,0x9,0x0,0x0,
0x10,0xa,0x0,0x0,0x38,0xa,0x0,0x0,
0x50,0xa,0x0,0x0,0x78,0xa,0x0,0x0,
0xa8,0xa,0x0,0x0,0xc0,0xa,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x51,0x0,0x74,0x0,
0x51,0x0,0x75,0x0,0x69,0x0,0x63,0x0,
0x6b,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x8,0x0,0x0,0x0,0x4b,0x0,0x69,0x0,
0x72,0x0,0x69,0x0,0x67,0x0,0x61,0x0,
0x6d,0x0,0x69,0x0,0x0,0x0,0x0,0x0,
0x10,0x0,0x0,0x0,0x6f,0x0,0x72,0x0,
0x67,0x0,0x2e,0x0,0x6b,0x0,0x64,0x0,
0x65,0x0,0x2e,0x0,0x6b,0x0,0x69,0x0,
0x72,0x0,0x69,0x0,0x67,0x0,0x61,0x0,
0x6d,0x0,0x69,0x0,0x0,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x4b,0x0,0x50,0x0,
0x6b,0x0,0x50,0x0,0x61,0x0,0x73,0x0,
0x73,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xe,0x0,0x0,0x0,0x6f,0x0,0x72,0x0,
0x67,0x0,0x2e,0x0,0x6b,0x0,0x64,0x0,
0x65,0x0,0x2e,0x0,0x70,0x0,0x6b,0x0,
0x70,0x0,0x61,0x0,0x73,0x0,0x73,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x9,0x0,0x0,0x0,0x52,0x0,0x65,0x0,
0x63,0x0,0x74,0x0,0x61,0x0,0x6e,0x0,
0x67,0x0,0x6c,0x0,0x65,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x72,0x0,0x6f,0x0,
0x6f,0x0,0x74,0x0,0x0,0x0,0x0,0x0,
0xc,0x0,0x0,0x0,0x4b,0x0,0x50,0x0,
0x6b,0x0,0x50,0x0,0x61,0x0,0x73,0x0,
0x73,0x0,0x2e,0x0,0x50,0x0,0x61,0x0,
0x73,0x0,0x73,0x0,0x0,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x70,0x0,0x61,0x0,
0x73,0x0,0x73,0x0,0x0,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x70,0x0,0x61,0x0,
0x73,0x0,0x73,0x0,0x49,0x0,0x64,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x63,0x0,0x6f,0x0,
0x6c,0x0,0x6f,0x0,0x72,0x0,0x0,0x0,
0x14,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x63,0x0,0x6f,0x0,0x6c,0x0,
0x6f,0x0,0x72,0x0,0x0,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x72,0x0,0x61,0x0,
0x64,0x0,0x69,0x0,0x75,0x0,0x73,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x49,0x0,0x6d,0x0,
0x61,0x0,0x67,0x0,0x65,0x0,0x0,0x0,
0xf,0x0,0x0,0x0,0x62,0x0,0x61,0x0,
0x63,0x0,0x6b,0x0,0x67,0x0,0x72,0x0,
0x6f,0x0,0x75,0x0,0x6e,0x0,0x64,0x0,
0x49,0x0,0x6d,0x0,0x61,0x0,0x67,0x0,
0x65,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x73,0x0,0x6f,0x0,
0x75,0x0,0x72,0x0,0x63,0x0,0x65,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x15,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x73,0x0,0x6f,0x0,0x75,0x0,
0x72,0x0,0x63,0x0,0x65,0x0,0x0,0x0,
0x8,0x0,0x0,0x0,0x66,0x0,0x69,0x0,
0x6c,0x0,0x6c,0x0,0x4d,0x0,0x6f,0x0,
0x64,0x0,0x65,0x0,0x0,0x0,0x0,0x0,
0x17,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x66,0x0,0x69,0x0,0x6c,0x0,
0x6c,0x0,0x4d,0x0,0x6f,0x0,0x64,0x0,
0x65,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x11,0x0,0x0,0x0,0x76,0x0,0x65,0x0,
0x72,0x0,0x74,0x0,0x69,0x0,0x63,0x0,
0x61,0x0,0x6c,0x0,0x41,0x0,0x6c,0x0,
0x69,0x0,0x67,0x0,0x6e,0x0,0x6d,0x0,
0x65,0x0,0x6e,0x0,0x74,0x0,0x0,0x0,
0x20,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x76,0x0,0x65,0x0,0x72,0x0,
0x74,0x0,0x69,0x0,0x63,0x0,0x61,0x0,
0x6c,0x0,0x41,0x0,0x6c,0x0,0x69,0x0,
0x67,0x0,0x6e,0x0,0x6d,0x0,0x65,0x0,
0x6e,0x0,0x74,0x0,0x0,0x0,0x0,0x0,
0xe,0x0,0x0,0x0,0x49,0x0,0x6d,0x0,
0x61,0x0,0x67,0x0,0x65,0x0,0x2e,0x0,
0x41,0x0,0x6c,0x0,0x69,0x0,0x67,0x0,
0x6e,0x0,0x54,0x0,0x6f,0x0,0x70,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x13,0x0,0x0,0x0,0x68,0x0,0x6f,0x0,
0x72,0x0,0x69,0x0,0x7a,0x0,0x6f,0x0,
0x6e,0x0,0x74,0x0,0x61,0x0,0x6c,0x0,
0x41,0x0,0x6c,0x0,0x69,0x0,0x67,0x0,
0x6e,0x0,0x6d,0x0,0x65,0x0,0x6e,0x0,
0x74,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x22,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x68,0x0,0x6f,0x0,0x72,0x0,
0x69,0x0,0x7a,0x0,0x6f,0x0,0x6e,0x0,
0x74,0x0,0x61,0x0,0x6c,0x0,0x41,0x0,
0x6c,0x0,0x69,0x0,0x67,0x0,0x6e,0x0,
0x6d,0x0,0x65,0x0,0x6e,0x0,0x74,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x12,0x0,0x0,0x0,0x49,0x0,0x6d,0x0,
0x61,0x0,0x67,0x0,0x65,0x0,0x2e,0x0,
0x41,0x0,0x6c,0x0,0x69,0x0,0x67,0x0,
0x6e,0x0,0x48,0x0,0x43,0x0,0x65,0x0,
0x6e,0x0,0x74,0x0,0x65,0x0,0x72,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x78,0x0,0x0,0x0,
0x10,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x78,0x0,0x0,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x79,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x68,0x0,0x65,0x0,
0x69,0x0,0x67,0x0,0x68,0x0,0x74,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x15,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x68,0x0,0x65,0x0,0x69,0x0,
0x67,0x0,0x68,0x0,0x74,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x77,0x0,0x69,0x0,
0x64,0x0,0x74,0x0,0x68,0x0,0x0,0x0,
0x14,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x77,0x0,0x69,0x0,0x64,0x0,
0x74,0x0,0x68,0x0,0x0,0x0,0x0,0x0,
0x12,0x0,0x0,0x0,0x68,0x0,0x61,0x0,
0x73,0x0,0x42,0x0,0x61,0x0,0x63,0x0,
0x6b,0x0,0x67,0x0,0x72,0x0,0x6f,0x0,
0x75,0x0,0x6e,0x0,0x64,0x0,0x43,0x0,
0x6f,0x0,0x6c,0x0,0x6f,0x0,0x72,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xf,0x0,0x0,0x0,0x62,0x0,0x61,0x0,
0x63,0x0,0x6b,0x0,0x67,0x0,0x72,0x0,
0x6f,0x0,0x75,0x0,0x6e,0x0,0x64,0x0,
0x43,0x0,0x6f,0x0,0x6c,0x0,0x6f,0x0,
0x72,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x54,0x0,0x68,0x0,
0x65,0x0,0x6d,0x0,0x65,0x0,0x0,0x0,
0x17,0x0,0x0,0x0,0x69,0x0,0x6d,0x0,
0x61,0x0,0x67,0x0,0x65,0x0,0x3a,0x0,
0x2f,0x0,0x2f,0x0,0x6f,0x0,0x72,0x0,
0x67,0x0,0x2e,0x0,0x6b,0x0,0x64,0x0,
0x65,0x0,0x2e,0x0,0x70,0x0,0x6b,0x0,
0x70,0x0,0x61,0x0,0x73,0x0,0x73,0x0,
0x2f,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x2f,0x0,0x62,0x0,
0x61,0x0,0x63,0x0,0x6b,0x0,0x67,0x0,
0x72,0x0,0x6f,0x0,0x75,0x0,0x6e,0x0,
0x64,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xe,0x0,0x0,0x0,0x69,0x0,0x6d,0x0,
0x70,0x0,0x6c,0x0,0x69,0x0,0x63,0x0,
0x69,0x0,0x74,0x0,0x48,0x0,0x65,0x0,
0x69,0x0,0x67,0x0,0x68,0x0,0x74,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x70,0x0,0x61,0x0,
0x72,0x0,0x65,0x0,0x6e,0x0,0x74,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xe,0x0,0x0,0x0,0x54,0x0,0x69,0x0,
0x6c,0x0,0x65,0x0,0x56,0x0,0x65,0x0,
0x72,0x0,0x74,0x0,0x69,0x0,0x63,0x0,
0x61,0x0,0x6c,0x0,0x6c,0x0,0x79,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x12,0x0,0x0,0x0,0x50,0x0,0x72,0x0,
0x65,0x0,0x73,0x0,0x65,0x0,0x72,0x0,
0x76,0x0,0x65,0x0,0x41,0x0,0x73,0x0,
0x70,0x0,0x65,0x0,0x63,0x0,0x74,0x0,
0x43,0x0,0x72,0x0,0x6f,0x0,0x70,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x8,0x0,0x0,0x0,0x41,0x0,0x6c,0x0,
0x69,0x0,0x67,0x0,0x6e,0x0,0x54,0x0,
0x6f,0x0,0x70,0x0,0x0,0x0,0x0,0x0,
0xc,0x0,0x0,0x0,0x41,0x0,0x6c,0x0,
0x69,0x0,0x67,0x0,0x6e,0x0,0x48,0x0,
0x43,0x0,0x65,0x0,0x6e,0x0,0x74,0x0,
0x65,0x0,0x72,0x0,0x0,0x0,0x0,0x0,
0x3,0x0,0x0,0x0,0x10,0x0,0x0,0x0,
0x2,0x0,0x0,0x0,0x4c,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x6,0x0,0x10,0x0,
0xff,0xff,0x0,0x0,0x1,0x0,0x0,0x0,
0x3,0x0,0x0,0x0,0x2,0x0,0x0,0x0,
0x7,0x0,0x10,0x0,0xff,0xff,0x0,0x0,
0x1,0x0,0x0,0x0,0x5,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x8,0x0,0x10,0x0,
0xff,0xff,0x0,0x0,0x54,0x0,0x0,0x0,
0xc,0x1,0x0,0x0,0x6,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x0,0x0,0xff,0xff,
0xff,0xff,0xff,0xff,0x0,0x0,0x2,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x6c,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x6c,0x0,0x0,0x0,0x6c,0x0,0x0,0x0,
0x0,0x0,0x3,0x0,0x6c,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xb4,0x0,0x0,0x0,
0xb,0x0,0x10,0x0,0xc,0x0,0x50,0x0,
0xb4,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xb4,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x9,0x0,0x0,0x0,0x8,0x0,0x0,0x0,
0xf,0x0,0x50,0x0,0xa,0x0,0x0,0x0,
0x5,0x0,0x0,0x20,0x12,0x0,0x50,0x0,
0xd,0x0,0x0,0x0,0x0,0x0,0x2,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x15,0x0,0x50,0x0,0x15,0x0,0xd0,0x0,
0xb,0x0,0x0,0x0,0x0,0x0,0x7,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x14,0x0,0x50,0x0,0x14,0x0,0xc0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x8,0x0,
0x1,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x18,0x0,0x50,0x0,0x18,0x0,0x50,0x0,
0x0,0x0,0x0,0x0,0xe,0x0,0x0,0x0,
0xf,0x0,0x0,0x0,0x0,0x0,0xff,0xff,
0xff,0xff,0xff,0xff,0x0,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x8,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x14,0x1,0x0,0x0,
0x18,0x0,0x50,0x0,0x19,0x0,0x90,0x0,
0x14,0x1,0x0,0x0,0x0,0x0,0x0,0x0,
0x14,0x1,0x0,0x0,0x0,0x0,0x0,0x0,
0x1f,0x0,0x0,0x0,0x0,0x0,0x7,0x0,
0x7,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x21,0x0,0x90,0x0,0x21,0x0,0x0,0x1,
0x1d,0x0,0x0,0x0,0x0,0x0,0x7,0x0,
0x6,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x20,0x0,0x90,0x0,0x20,0x0,0x10,0x1,
0x1c,0x0,0x0,0x0,0x0,0x0,0x2,0x0,
0x1,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x1f,0x0,0x90,0x0,0x1f,0x0,0xc0,0x0,
0x1a,0x0,0x0,0x0,0x0,0x0,0x7,0x0,
0x5,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x1e,0x0,0x90,0x0,0x1e,0x0,0xc0,0x0,
0x17,0x0,0x0,0x0,0x0,0x0,0x7,0x0,
0x4,0x0,0x0,0x0,0x19,0x0,0x0,0x0,
0x1d,0x0,0x90,0x0,0x1d,0x0,0xe0,0x1,
0x14,0x0,0x0,0x0,0x0,0x0,0x7,0x0,
0x3,0x0,0x0,0x0,0x16,0x0,0x0,0x0,
0x1c,0x0,0x90,0x0,0x1c,0x0,0xc0,0x1,
0x12,0x0,0x0,0x0,0x0,0x0,0x7,0x0,
0x2,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x1b,0x0,0x90,0x0,0x1b,0x0,0x30,0x1,
0x10,0x0,0x0,0x0,0x0,0x0,0x7,0x0,
0x1,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x1a,0x0,0x90,0x0,0x1a,0x0,0x10,0x1,
0x0,0x0,0x0,0x0
};
extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[] = {
{ 1, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType::fromType<QUrl>();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for source at line 26, column 9
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_0, markStack);
    aotContext->mark(v2_16, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_0 = nullptr;
QObject *v2_16 = nullptr;
QString v2_12;
QString v2_18;
QString v2_20;
QString v2_24;
QString v2_2;
QString v2_6;
QUrl c2_32;
QUrl v2_26;
QUrl v2_30;
bool v2_8;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
while (!aotContext->loadContextIdLookup(9, &s.v2_0)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
aotContext->initLoadContextIdLookup(9);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QUrl *>(argv[0]) = QUrl();
}
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
while (!aotContext->getObjectLookup(10, s.v2_0, &s.v2_2)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
aotContext->initGetObjectLookup(10, s.v2_0);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QUrl *>(argv[0]) = QUrl();
}
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_LoadRuntimeString
s.v2_6 = QStringLiteral("");
{
}
// generate_CmpStrictNotEqual
s.v2_8 = s.v2_2 != s.v2_6;
{
}
// generate_JumpFalse
if (!s.v2_8) {
    goto label_0;
}
{
}
// generate_LoadRuntimeString
s.v2_12 = QStringLiteral("image://org.kde.pkpass/");
{
}
// generate_StoreReg
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(18);
#endif
while (!aotContext->loadContextIdLookup(11, &s.v2_16)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(18);
#endif
aotContext->initLoadContextIdLookup(11);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QUrl *>(argv[0]) = QUrl();
}
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(20);
#endif
while (!aotContext->getObjectLookup(12, s.v2_16, &s.v2_18)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(20);
#endif
aotContext->initGetObjectLookup(12, s.v2_16);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QUrl *>(argv[0]) = QUrl();
}
return;
}
}
{
}
// generate_Add
s.v2_20 = QString(std::move(s.v2_12) + std::move(s.v2_18));
{
}
// generate_StoreReg
{
}
// generate_LoadRuntimeString
s.v2_24 = QStringLiteral("/background");
{
}
// generate_Add
s.v2_26 = QUrl(QString(std::move(s.v2_20) + std::move(s.v2_24)));
{
}
// generate_Jump
{
s.c2_32 = s.v2_26;
    goto label_1;
}
label_0:;
// generate_LoadRuntimeString
s.v2_30 = QUrl(QStringLiteral(""));
{
s.c2_32 = s.v2_30;
}
label_1:;
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<QUrl *>(argv[0]) = std::move(s.c2_32);
}
return;
}
 },{ 2, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = []() { static const auto t = QMetaType::fromName("QQuickImage::FillMode"); return t; }();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for fillMode at line 27, column 9
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_0, markStack);
    aotContext->mark(v2_6, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_0 = nullptr;
QObject *v2_6 = nullptr;
bool v2_10;
double v2_2;
double v2_8;
int c2_24;
int v2_16;
int v2_22;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
while (!aotContext->loadContextIdLookup(13, &s.v2_0)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
aotContext->initLoadContextIdLookup(13);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    const QMetaType returnType = []() { static const auto t = QMetaType::fromName("QQuickImage::FillMode"); return t; }();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0]);
 }
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
while (!aotContext->getObjectLookup(14, s.v2_0, &s.v2_2)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
aotContext->initGetObjectLookup(14, s.v2_0);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    const QMetaType returnType = []() { static const auto t = QMetaType::fromName("QQuickImage::FillMode"); return t; }();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0]);
 }
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(8);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(15, &s.v2_6)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(8);
#endif
aotContext->initLoadScopeObjectPropertyLookup(15);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    const QMetaType returnType = []() { static const auto t = QMetaType::fromName("QQuickImage::FillMode"); return t; }();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0]);
 }
return;
}
}
{
}
// generate_GetLookup
{
QVariant retrieved;
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(10);
#endif
while (!aotContext->getObjectLookup(16, s.v2_6, &retrieved)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(10);
#endif
aotContext->initGetObjectLookupAsVariant(16, s.v2_6);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    const QMetaType returnType = []() { static const auto t = QMetaType::fromName("QQuickImage::FillMode"); return t; }();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0]);
 }
return;
}
}
s.v2_8 = aotContext->engine->fromVariant<double>(std::move(retrieved));
}
{
}
// generate_CmpLt
s.v2_10 = s.v2_2 < s.v2_8;
{
}
// generate_JumpFalse
if (!s.v2_10) {
    goto label_0;
}
{
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(18);
#endif
while (!aotContext->getEnumLookup(18, &s.v2_16)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(18);
#endif
aotContext->initGetEnumLookup(18, []() { static const auto t = QMetaType::fromName("QQuickImage*"); return t; }().metaObject(), "FillMode", "TileVertically");
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    const QMetaType returnType = []() { static const auto t = QMetaType::fromName("QQuickImage::FillMode"); return t; }();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0]);
 }
return;
}
}
{
}
// generate_Jump
{
s.c2_24 = s.v2_16;
    goto label_1;
}
label_0:;
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(24);
#endif
while (!aotContext->getEnumLookup(20, &s.v2_22)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(24);
#endif
aotContext->initGetEnumLookup(20, []() { static const auto t = QMetaType::fromName("QQuickImage*"); return t; }().metaObject(), "FillMode", "PreserveAspectCrop");
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    const QMetaType returnType = []() { static const auto t = QMetaType::fromName("QQuickImage::FillMode"); return t; }();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0]);
 }
return;
}
}
{
s.c2_24 = s.v2_22;
}
label_1:;
{
}
// generate_Ret
if (argv[0]) {
    const QMetaType returnType = QMetaType::fromType<int>();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0], &s.c2_24);
}
return;
}
 },{ 3, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = []() { static const auto t = QMetaType::fromName("QQuickImage::VAlignment"); return t; }();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for verticalAlignment at line 28, column 9
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
int v2_2;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
while (!aotContext->getEnumLookup(22, &s.v2_2)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
aotContext->initGetEnumLookup(22, []() { static const auto t = QMetaType::fromName("QQuickImage*"); return t; }().metaObject(), "VAlignment", "AlignTop");
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    const QMetaType returnType = []() { static const auto t = QMetaType::fromName("QQuickImage::VAlignment"); return t; }();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0]);
 }
return;
}
}
{
}
{
}
// generate_Ret
if (argv[0]) {
    const QMetaType returnType = QMetaType::fromType<int>();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0], &s.v2_2);
}
return;
}
 },{ 4, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = []() { static const auto t = QMetaType::fromName("QQuickImage::HAlignment"); return t; }();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for horizontalAlignment at line 29, column 9
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
int v2_2;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
while (!aotContext->getEnumLookup(24, &s.v2_2)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
aotContext->initGetEnumLookup(24, []() { static const auto t = QMetaType::fromName("QQuickImage*"); return t; }().metaObject(), "HAlignment", "AlignHCenter");
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    const QMetaType returnType = []() { static const auto t = QMetaType::fromName("QQuickImage::HAlignment"); return t; }();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0]);
 }
return;
}
}
{
}
{
}
// generate_Ret
if (argv[0]) {
    const QMetaType returnType = QMetaType::fromType<int>();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0], &s.v2_2);
}
return;
}
 },{ 5, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType::fromType<double>();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for x at line 30, column 9
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_4, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_4 = nullptr;
double v2_0;
double v2_10;
double v2_13;
double v2_15;
double v2_6;
double v2_8;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(25, &s.v2_0)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
aotContext->initLoadScopeObjectPropertyLookup(25);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(6);
#endif
while (!aotContext->loadContextIdLookup(26, &s.v2_4)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(6);
#endif
aotContext->initLoadContextIdLookup(26);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(8);
#endif
while (!aotContext->getObjectLookup(27, s.v2_4, &s.v2_6)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(8);
#endif
aotContext->initGetObjectLookup(27, s.v2_4);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_Sub
s.v2_8 = (s.v2_0 - s.v2_6);
{
}
// generate_UMinus
s.v2_10 = -s.v2_8;
{
}
// generate_StoreReg
{
}
// generate_LoadInt
s.v2_13 = double(2);
{
}
// generate_Div
QT_WARNING_PUSH
QT_WARNING_DISABLE_MSVC(4723) // potential divide by 0
s.v2_15 = (s.v2_10 / s.v2_13);
QT_WARNING_POP
{
}
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<double *>(argv[0]) = s.v2_15;
}
return;
}
 },{ 6, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType::fromType<double>();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for height at line 32, column 9
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_0, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_0 = nullptr;
double v2_2;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
while (!aotContext->loadContextIdLookup(28, &s.v2_0)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
aotContext->initLoadContextIdLookup(28);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
while (!aotContext->getObjectLookup(29, s.v2_0, &s.v2_2)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
aotContext->initGetObjectLookup(29, s.v2_0);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<double *>(argv[0]) = s.v2_2;
}
return;
}
 },{ 7, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType::fromType<double>();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for width at line 33, column 9
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_0, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_0 = nullptr;
double v2_2;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
while (!aotContext->loadContextIdLookup(30, &s.v2_0)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
aotContext->initLoadContextIdLookup(30);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
while (!aotContext->getObjectLookup(31, s.v2_0, &s.v2_2)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
aotContext->initGetObjectLookup(31, s.v2_0);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<double *>(argv[0]) = s.v2_2;
}
return;
}
 },{ 0, 0, nullptr, nullptr }};
}
}
